# -*- coding: utf-8 -*-

from loguru import logger

from app.controllers.equipment.switch import Switch, SwitchSet
from app.models.domain.devices import ACATFUSwitchSetRequest
from app.schemas.equipment import PAU


class PAUSwitch(Switch):
    def __init__(self, equipment: PAU):
        super(PAUSwitch, self).__init__(equipment)

    def break_time_action(self, begin: str, end: str, is_workday: bool) -> SwitchSet:
        if self._equip.in_cloud_status:
            if is_workday:
                if begin and end:
                    switch_flag = True
                    if begin <= end:
                        if begin <= self._now_time <= end:
                            switch_flag = False
                    else:
                        if not end <= self._now_time <= begin:
                            switch_flag = False

                    if not switch_flag:
                        action = SwitchSet.off
                    else:
                        action = SwitchSet.hold
                else:
                    action = SwitchSet.hold
            else:
                action = SwitchSet.hold
        else:
            action = SwitchSet.hold

        return action


@logger.catch()
async def build_acatfu_switch_set(params: ACATFUSwitchSetRequest) -> SwitchSet:
    pau = PAU(
        running_status=params.running_status,
        in_cloud_status=params.in_cloud_status,
        on_time=params.on_time,
        off_time=params.off_time,
    )
    pau_switch_controller = PAUSwitch(pau)
    action = await pau_switch_controller.build_next_action(params.is_workday)
    break_action = pau_switch_controller.break_time_action(
        params.break_start_time, params.break_end_time, params.is_workday
    )
    if break_action == "off":
        action = SwitchSet.off

    return action
